@@ -44,6 +44,8 @@
 
 using namespace std;
 
+// From bpp-core:
+#include <Bpp/Version.h>
 #include <Bpp/App/BppApplication.h>
 #include <Bpp/App/ApplicationTools.h>
 #include <Bpp/Io/FileTools.h>
@@ -55,7 +57,7 @@ using namespace std;
 #include <Bpp/Numeric/VectorTools.h>
 #include <Bpp/Numeric/AutoParameter.h>
 
-// From SeqLib:
+// From bpp-seq:
 #include <Bpp/Seq/SiteTools.h>
 #include <Bpp/Seq/Alphabet/Alphabet.h>
 #include <Bpp/Seq/Container/VectorSiteContainer.h>
@@ -63,14 +65,19 @@ using namespace std;
 #include <Bpp/Seq/Container/SiteContainerTools.h>
 #include <Bpp/Seq/App/SequenceApplicationTools.h>
 
-// From PhylLib:
+// From bpp-phyl:
 #include <Bpp/Phyl/Tree.h>
-#include <Bpp/Phyl/Likelihood.all>
 #include <Bpp/Phyl/PatternTools.h>
 #include <Bpp/Phyl/App/PhylogeneticsApplicationTools.h>
 #include <Bpp/Phyl/OptimizationTools.h>
-#include <Bpp/Phyl/Model.all>
+#include <Bpp/Phyl/Model/SubstitutionModelSetTools.h>
+#include <Bpp/Phyl/Model/AbstractBiblioMixedSubstitutionModel.h>
+#include <Bpp/Phyl/Model/MixedSubstitutionModel.h>
+#include <Bpp/Phyl/Model/MixtureOfASubstitutionModel.h>
+#include <Bpp/Phyl/Model/MixtureOfSubstitutionModels.h>
 #include <Bpp/Phyl/Model/RateDistribution/ConstantRateDistribution.h>
+#include <Bpp/Phyl/Likelihood/RHomogeneousMixedTreeLikelihood.h>
+#include <Bpp/Phyl/Likelihood/RNonHomogeneousMixedTreeLikelihood.h>
 #include <Bpp/Phyl/Io/Newick.h>
 
 using namespace bpp;
@@ -91,8 +98,8 @@ int main(int args, char** argv)
 {
   cout << "******************************************************************" << endl;
   cout << "*     Bio++ Computation of site likelihoods inside mixed models  *" << endl;
-  cout << "*                        Version 2.2.0.                          *" << endl;
-  cout << "* Author: L. Guéguen                       Last Modif.: 25/09/14 *" << endl;
+  cout << "*                        Version " << BPP_VERSION << ".                          *" << endl;
+  cout << "* Author: L. Guéguen                       Last Modif.: " << BPP_REL_DATE << " *" << endl;
   cout << "******************************************************************" << endl;
   cout << endl;
 
@@ -108,7 +115,7 @@ int main(int args, char** argv)
     bppmixedlikelihoods.startTimer();
 
     Alphabet* alphabet = SequenceApplicationTools::getAlphabet(bppmixedlikelihoods.getParams(), "", false);
-    auto_ptr<GeneticCode> gCode;
+    unique_ptr<GeneticCode> gCode;
     CodonAlphabet* codonAlphabet = dynamic_cast<CodonAlphabet*>(alphabet);
     if (codonAlphabet) {
       string codeDesc = ApplicationTools::getStringParameter("genetic_code", bppmixedlikelihoods.getParams(), "Standard", "", true, true);
@@ -188,9 +195,12 @@ int main(int args, char** argv)
         rateFreqs = vector<double>(n, 1. / (double)n); // Equal rates assumed for now, may be changed later (actually, in the most general case,
         // we should assume a rate distribution for the root also!!!
       }
-      FrequenciesSet* rootFreqs = PhylogeneticsApplicationTools::getRootFrequenciesSet(alphabet, gCode.get(), sites, bppmixedlikelihoods.getParams(), rateFreqs);
+      
+      std::map<std::string, std::string> aliasFreqNames;
+
+      FrequenciesSet* rootFreqs = PhylogeneticsApplicationTools::getRootFrequenciesSet(alphabet, gCode.get(), sites, bppmixedlikelihoods.getParams(), aliasFreqNames, rateFreqs);
       vector<string> globalParameters = ApplicationTools::getVectorParameter<string>("nonhomogeneous_one_per_branch.shared_parameters", bppmixedlikelihoods.getParams(), ',', "");
-      modelSet = dynamic_cast<MixedSubstitutionModelSet*>(SubstitutionModelSetTools::createNonHomogeneousModelSet(model, rootFreqs, tree, globalParameters));
+      modelSet = dynamic_cast<MixedSubstitutionModelSet*>(SubstitutionModelSetTools::createNonHomogeneousModelSet(model, rootFreqs, tree, aliasFreqNames, globalParameters));
       model = 0;
       tl = new RNonHomogeneousMixedTreeLikelihood(*tree, *sites, modelSet, rDist, true);
     }
@@ -217,10 +227,11 @@ int main(int args, char** argv)
     }
     else
       throw Exception("Unknown option for nonhomogeneous: " + nhOpt);
+
     tl->initialize();
 
     double logL = tl->getValue();
-    if (isinf(logL))
+    if (std::isinf(logL))
     {
       // This may be due to null branch lengths, leading to null likelihood!
       ApplicationTools::displayWarning("!!! Warning!!! Likelihood is zero.");
@@ -235,7 +246,7 @@ int main(int args, char** argv)
       tl->matchParametersValues(pl);
       logL = tl->getValue();
     }
-    if (isinf(logL))
+    if (std::isinf(logL))
     {
       ApplicationTools::displayError("!!! Unexpected likelihood == 0.");
       ApplicationTools::displayError("!!! Looking at each site:");
@@ -290,24 +301,23 @@ int main(int args, char** argv)
       exit(-1);
     }
 
-    bool fromBiblio=false;
-    
     const AbstractBiblioMixedSubstitutionModel* ptmp = dynamic_cast<const AbstractBiblioMixedSubstitutionModel*>(p0);
     if (ptmp) {
       p0 = ptmp->getMixedModel().clone();
+
       if (nhOpt == "no")
         model = p0;
       else {
         modelSet->replaceModel(nummodel-1, p0);
         modelSet->isFullySetUpFor(*tree);
       }
-      fromBiblio=true;
     }
-
+    
     //////////////////////////////////////////////////
     // Case of a MixtureOfSubstitutionModels
 
     MixtureOfSubstitutionModels* pMSM = dynamic_cast<MixtureOfSubstitutionModels*>(p0);
+
     if (pMSM)
     {
       vector<string> colNames;
@@ -373,18 +383,25 @@ int main(int args, char** argv)
       if (pMSM2 != NULL)
       {
         size_t nummod = pMSM2->getNumberOfModels();
-        if (fromBiblio && (parname == ""))
+        if (parname == "")
         {
           ParameterList pl=pMSM2->getParameters();
 
           for (size_t i2 = 0; i2 < pl.size(); i2++)
           {
             string pl2n = pl[i2].getName();
-            string par2 = pl2n.substr(0,pl2n.find("_")) + "_1";
-            Vint vnmod = pMSM2->getSubmodelNumbers(par2);
-            if (vnmod.size() == 1) {
-              parname=pl2n.substr(0,pl2n.find("_"));
-              break;
+
+            if (dynamic_cast<const ConstantDistribution*>(pMSM2->getDistribution(pl2n))==NULL)
+            {
+              parname=pl2n;
+
+              while (parname.size()>0 && pMSM2->getDistribution(parname)==NULL)
+                parname=pl2n.substr(0,pl2n.rfind("_"));
+
+              if (parname.size()>0){
+                ApplicationTools::displayResult("likelihoods.parameter_name", parname);
+                break;
+              }
             }
           }
         }
@@ -408,7 +425,9 @@ int main(int args, char** argv)
         }
 
         size_t nbcl = vvnmod.size();
-
+        if (nbcl==0)
+          throw Exception("Parameter " + parname + " is not mixed.");
+        
         Vdouble vprob = pMSM2->getProbabilities();
 
         vector<vector<double> > vvprob;
@@ -430,14 +449,14 @@ int main(int args, char** argv)
         colNames.push_back("Sites");
 
         Vdouble dval;
-        for (unsigned int i = 0; i < nbcl; i++)
+        for (size_t i = 0; i < nbcl; i++)
         {
           SubstitutionModel* pSM = pMSM2->getNModel(static_cast<size_t>(vvnmod[i][0]));
           double valPar = pSM->getParameterValue(pSM->getParameterNameWithoutNamespace(parname));
           dval.push_back(valPar);
           colNames.push_back("Ll_" + parname + "=" + TextTools::toString(valPar));
         }
-        for (unsigned int i = 0; i < nbcl; i++)
+        for (size_t i = 0; i < nbcl; i++)
           colNames.push_back("Pr_" + parname + "=" + TextTools::toString(dval[i]));
 
         colNames.push_back("mean");
@@ -445,7 +464,7 @@ int main(int args, char** argv)
         DataTable* rates = new DataTable(nSites, colNames.size());
         rates->setColumnNames(colNames);
 
-        for (unsigned int i = 0; i < nSites; i++)
+        for (size_t i = 0; i < nSites; i++)
         {
           const Site* currentSite = &sites->getSite(i);
           int currentSitePosition = currentSite->getPosition();
@@ -491,14 +510,14 @@ int main(int args, char** argv)
           ApplicationTools::displayResult("Probability", TextTools::toString(vsprob[i], 15));
         }
 
-        for (unsigned int j = 0; j < nSites; j++)
+        for (size_t j = 0; j < nSites; j++)
         {
           Vdouble vd;
-          for (unsigned int i = 0; i < nbcl; i++)
+          for (size_t i = 0; i < nbcl; i++)
             vd.push_back(std::log(vsprob[i])+vvd[i][j]);
           
           VectorTools::logNorm(vd);
-          for (unsigned int i = 0; i < nbcl; i++)
+          for (size_t i = 0; i < nbcl; i++)
             (*rates)(j,nbcl + i + 1) = TextTools::toString(std::exp(vd[i]));
           (*rates)(j, 2 * nbcl + 1) = TextTools::toString(VectorTools::sumExp(vd, dval));
         }
